<template>
  <div class="full-page bg">
    <div class="search-container" element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
         element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
      <el-form ref="form" :model="searchForm" label-width="auto" style="width: 100%">
        <el-row :gutter="20">
          <el-col :span="5">
            <el-form-item label="项目名称">
              <el-input v-model="querys[0].value" clearable placeholder="请输入项目名称">
              </el-input>
            </el-form-item>
          </el-col>

          <el-col :span="5">
            <el-form-item label="项目类型">
              <dict-select dictCode="ljlcqh_xmfl" :hasDefaultOption="true" clearable
                           v-model="querys[1].value" style="width: 100%" @select="(val, obj) =>
                                    hanldeCommonSelect(val, obj, 'project')
                                    " placeholder="请选择项目类型" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="专项小组">
              <dict-select dictCode="wg_zxxz" :hasDefaultOption="true" clearable
                           v-model="querys[3].value" style="width: 100%" placeholder="请选择专项小组" />
            </el-form-item>
          </el-col>
          <el-col :span="2">
            <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="handleSearch(1)">
              搜索
            </el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <el-row :gutter="10" class="main-table-container flex">
      <el-col :span="24" class="table-container" ref="contentPanel" style="padding: 20px">
        <div style="margin-bottom: 10px" ref="btnPanel"></div>
        <div :style="{ width: '100%', height: `${tableMaxHeight}` + 'px' }">
          <el-table stripe size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
                    :max-height="tableMaxHeight" :style="{ width: '100%' }"
                    @selection-change="handleSelectionChange">
            <el-table-column type="index" min-width="160" show-overflow-tooltip label="序号"
                             align="center">
            </el-table-column>
            <el-table-column prop="projectName" min-width="160" show-overflow-tooltip label="项目名称"
                             align="center">
            </el-table-column>
            <el-table-column prop="projectName" show-overflow-tooltip label="项目类型" align="center">
              <template v-slot="{ row }">
                {{
                  getDictName('ljlcqh_xmfl', row.projectType)
                }}
              </template>
            </el-table-column>
            <el-table-column prop="unitName" min-width="100" show-overflow-tooltip label="责任单位"
                             align="center">
            </el-table-column>
            <el-table-column prop="groupName" min-width="120" show-overflow-tooltip label="专项小组"
                             align="center">
            </el-table-column>
            <!-- <el-table-column prop="createTime" min-width="120" show-overflow-tooltip label="填报时间"
                align="center">
            </el-table-column> -->
            <el-table-column prop="status" min-width="100" show-overflow-tooltip label="审核状态" align="center">
              <template v-slot="{ row }">
                <el-tag v-if="!row.status && row.status !== 0" type="warning">待更新</el-tag>
                <el-tag v-else :type="row.status % 2 === 0 ? ( row.status !== 0 ? 'danger' : 'info') : row.status == 5 ? 'success' : ''"
                >{{ getDictName('ljlcqh_shzt', row.status) }}</el-tag>
              </template>
            </el-table-column>
            <el-table-column show-overflow-tooltip align="center" fixed="right" width="180" label="操作">
              <template v-slot="{ row }">
                <el-link icon="el-icon-s-check" type="danger" :underline="false"
                         class="cloumn-btn wait-updata-btn" v-if="!row.status && row.status !== 0"
                         @click="handleDbClick(row, '推进更新')">
                  待更新
                </el-link>
                <el-link v-if="row.status == 2 || row.status == 4 || row.status == 5"
                         icon="el-icon-refresh" type="primary" class="cloumn-btn" :underline="false" @click="
                                        handleDbClick(row, '推进更新')">
                  更新
                </el-link>
                <el-link v-if="row.status == 0" icon="el-icon-edit" type="primary" class="cloumn-btn"
                         :underline="false" @click="
                                        handleDbClick(row, '编辑')">
                  编辑
                </el-link>
                <el-link v-if="row.status > 0" icon="el-icon-view" type="primary" :underline="false"
                         class="cloumn-btn" @click="
                                        handleDbClick(row, '编辑',false)
                                        ">
                  编辑
                </el-link>
                <el-link v-if="row.status == 1" icon="el-icon-refresh-left" type="danger"
                         :underline="false" class="cloumn-btn wait-updata-btn"
                         @click="propelRevocation(row)">
                  撤回
                </el-link>
              </template>
            </el-table-column>
          </el-table>
        </div>
        <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="queryParam.pageBean"
                    @size-change="handleSizeChange" @current-change="handleCurrentChange" />
      </el-col>
    </el-row>
    <projects-dialog ref="ProjectsDialog" @getData="getData"></projects-dialog>
  </div>
</template>

<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import utils from '@/utils.js'
import projectsAPI from '@/api/SixthConferenceImplementation/index.js'
import projectsDialog from './components/projectsDialog.vue'
export default {
  name: 'projectCreated',
  components: {
    pagination,
    projectsDialog,
  },
  mixins: [TableMixin],
  data() {
    return {
      markLoading: false,
      searchForm: {},
      loading: false,
      tableData: [],
      multipleSelection: [],
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'project_name_',
          relation: 'AND',
          value: '',
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'project_type_',
          relation: 'AND',
          value: '',
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'send_status_',
          relation: 'AND',
          value: '1',
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'group_name_',
          relation: 'AND',
          value: '',
        },
      ],
      queryParam: {
        pageBean: {
          page: 1,
          pageSize: 20,
          total: 0,
        },
      },
    }
  },
  created() {
    this.getData()
  },
  mounted() { },
  methods: {
    // 撤回
    propelRevocation(row) {
      this.$confirm('确认撤回已上报数据吗？', this.$t('common.tips'), {
        confirmButtonText: this.$t('common.confirm'),
        cancelButtonText: this.$t('common.cancel'),
        type: 'warning',
      }).then(() => {
        this.markLoading = true
        let data = {
          id: row.detailsId,
          status: 0
        }
        projectsAPI.propelRevocation(data).then(res => {
          if (res.state) {
            this.$message.success('撤回成功')
            row.status = 0
            this.markLoading = false
          }
        })
      })
    },
    selectHandle(row) {
      if (row.closing == 1) {
        return true
      }
    },
    // 下发状态筛选
    handleCommand(command, typeIndex) {
      this.querys[typeIndex].value = command
      this.handleSearch(1)
    },
    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    handleSearch(page) {
      this.queryParam.querys = []
      this.querys.forEach((item) => {
        if (item.value !== undefined) {
          this.queryParam.querys.push(item)
        }
      })
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.getData()
    },
    // 下发
    handlePublish(data) {
      this.$confirm(
        this.$t('确认下发选中数据吗？'),
        this.$t('common.tips'),
        {
          confirmButtonText: this.$t('common.confirm'),
          cancelButtonText: this.$t('common.cancel'),
          type: 'warning',
        }
      ).then(() => {
        projectsAPI.publishPorject([data]).then((res) => {
          console.log(res, 'this.getData()')
          this.getData()
        })
      })
    },
    //获取数据
    getData() {
      this.loading = true
      this.tableData = []
      projectsAPI.taskImplementation(this.queryParam, status).then((res) => {
        if (res.rows) {
          this.tableData = res.rows
          this.queryParam.pageBean.page = res.page
          this.queryParam.pageBean.total = res.total
          this.$set(this.tableData)
          this.loading = false
        }
      })
    },
    //修改
    handleDbClick(data, title,type) {
      this.$refs.ProjectsDialog.edit(data, title,type)
    },
    //详情
    handleDetailsk(data, type) {
      this.$refs.ProjectsDialog.detail(data, type)
    },
    //表格选中
    handleSelectionChange(val) {
      this.multipleSelection = []
      this.$refs.multipleSelection.selection.forEach((item) => {
        this.multipleSelection.push(item.id)
      })
    },
    //展示数量
    handleSizeChange(val) {
      this.queryParam.pageBean.pageSize = val
      this.handleSearch(1)
    },
    //表格页数
    handleCurrentChange(val) {
      this.queryParam.pageBean.page = val
      this.handleSearch(val)
    },
  },
}
</script>

<style lang="scss" scoped>
.wait-updata-btn {
  border: 1px solid #f56c6c !important;

  &:hover {
    background-color: #f56c6c !important;
    color: #fff !important;
    border-color: #f56c6c !important;
  }
}

.common-tree-container {
  height: calc(100% - 70px);
  margin-top: 0.52083vw;
  padding: 1.04167vw 1.04167vw;
  background-color: #fff;
  position: relative;
  box-sizing: border-box;
  overflow-y: auto;
  border-radius: 20px;
  box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
  display: flex;
  align-items: center;

  i {
    font-size: 16px;
    margin-left: 5px;
    font-weight: 600;
    cursor: pointer;
  }
}

.cloumn-btn {
  border: 1px solid #2761ff;
  padding: 3px 10px;
  border-radius: 5px;

  &:nth-child(1) {
    margin-right: 5px;
  }

  &:nth-child(2) {
    margin-right: 5px;
  }

  &:nth-child(1):hover {
    background-color: #2761ff;
    color: #fff;
  }

  &:nth-child(2):hover {
    background-color: #2761ff;
    color: #fff;
  }

  // &:nth-child(2):hover {
  //   background-color: #f56c6c;
  //   color: #fff;
  //   border-color: #f56c6c;
  // }
  /deep/ i,
  span {
    font-size: 16px;
  }
}
</style>
